@@ -301,10 +301,12 @@ impl_Bonobo_Control_setWindowId (PortableServer_Servant  servant,
 		/* Create the new plug */
 		control->priv->plug = bonobo_plug_new (x11_id);
 
-		gtk_signal_connect (GTK_OBJECT (control->priv->plug), "destroy_event",
-				    GTK_SIGNAL_FUNC (bonobo_control_plug_destroy_event_cb), control);
-		gtk_signal_connect (GTK_OBJECT (control->priv->plug), "destroy",
-				    GTK_SIGNAL_FUNC (bonobo_control_plug_destroy_cb), control);
+		gtk_signal_connect_while_alive (GTK_OBJECT (control->priv->plug), "destroy_event",
+						GTK_SIGNAL_FUNC (bonobo_control_plug_destroy_event_cb),
+						control, GTK_OBJECT (control));
+		gtk_signal_connect_while_alive (GTK_OBJECT (control->priv->plug), "destroy",
+						GTK_SIGNAL_FUNC (bonobo_control_plug_destroy_cb),
+						control, GTK_OBJECT (control));
 
 		/*
 		 * Put the control widget inside the plug.  If we
