@@ -255,8 +255,7 @@ toolbar_build_control (BonoboUISync     *sync,
 			sync->engine, node);
 
 		if (control != CORBA_OBJECT_NIL) {
-			item = bonobo_ui_toolbar_control_item_new (
-				bonobo_object_dup_ref (control, NULL));
+			item = bonobo_ui_toolbar_control_item_new (control);
 
 			if (!item)
 				return NULL;
@@ -597,15 +596,6 @@ config_verb_fn (BonoboUIEngineConfig *config,
 		bonobo_ui_engine_config_serialize (config);
 }
 
-static void
-toolbar_style_changed (BonoboUIToolbar *toolbar, gpointer data)
-{
-	GnomeDock *dock;
-
-	dock = (GnomeDock *) data;
-	gtk_widget_queue_resize (GTK_WIDGET (dock));
-}
-
 static GnomeDockItem *
 create_dockitem (BonoboUISyncToolbar *sync,
 		 BonoboUINode        *node,
@@ -705,9 +695,6 @@ create_dockitem (BonoboUISyncToolbar *sync,
 
 		
 	toolbar = BONOBO_UI_TOOLBAR (bonobo_ui_toolbar_new ());
-	gtk_signal_connect (GTK_OBJECT (toolbar), "set_style",
-                            GTK_SIGNAL_FUNC (toolbar_style_changed),
-                            sync->dock);
 
 	gtk_container_add (GTK_CONTAINER (item),
 			   GTK_WIDGET (toolbar));
