@@ -13,7 +13,7 @@
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkwindow.h>
 #include <bonobo/bonobo-object.h>
-#include <bonobo/bonobo-ui-xml.h>
+#include <bonobo/bonobo-ui-engine.h>
 
 #define BONOBO_TYPE_WINDOW        (bonobo_window_get_type ())
 #define BONOBO_WINDOW(o)          (GTK_CHECK_CAST ((o), BONOBO_TYPE_WINDOW, BonoboWindow))
@@ -46,21 +46,27 @@ void                 bonobo_window_set_contents                   (BonoboWindow
 								   GtkWidget         *contents);
 GtkWidget           *bonobo_window_get_contents                   (BonoboWindow      *win);
 
-void                 bonobo_window_freeze                         (BonoboWindow      *win);
 
-void                 bonobo_window_thaw                           (BonoboWindow      *win);
+BonoboUIEngine      *bonobo_window_get_ui_engine                  (BonoboWindow      *win);
 
 void                 bonobo_window_set_name                       (BonoboWindow      *win,
 								   const char        *win_name);
 
 char                *bonobo_window_get_name                       (BonoboWindow      *win);
 
-BonoboUIXmlError     bonobo_window_xml_merge                      (BonoboWindow      *win,
+GtkAccelGroup       *bonobo_window_get_accel_group                (BonoboWindow      *win);
+
+/* Mostly deprecated API; see bonobo-ui-engine.h */
+void                 bonobo_window_freeze                         (BonoboWindow      *win);
+
+void                 bonobo_window_thaw                           (BonoboWindow      *win);
+
+BonoboUIError        bonobo_window_xml_merge                      (BonoboWindow      *win,
 								   const char        *path,
 								   const char        *xml,
 								   const char        *component);
 
-BonoboUIXmlError     bonobo_window_xml_merge_tree                 (BonoboWindow      *win,
+BonoboUIError        bonobo_window_xml_merge_tree                 (BonoboWindow      *win,
 								   const char        *path,
 								   BonoboUINode      *tree,
 								   const char        *component);
@@ -72,22 +78,20 @@ char                *bonobo_window_xml_get                        (BonoboWindow
 gboolean             bonobo_window_xml_node_exists                (BonoboWindow      *win,
 								   const char        *path);
 
-BonoboUIXmlError     bonobo_window_xml_rm                         (BonoboWindow      *win,
+BonoboUIError        bonobo_window_xml_rm                         (BonoboWindow      *win,
 								   const char        *path,
 								   const char        *by_component);
 
-BonoboUIXmlError     bonobo_window_object_set                     (BonoboWindow      *win,
+BonoboUIError        bonobo_window_object_set                     (BonoboWindow      *win,
 								   const char        *path,
 								   Bonobo_Unknown     object,
 								   CORBA_Environment *ev);
 
-BonoboUIXmlError     bonobo_window_object_get                     (BonoboWindow      *win,
+BonoboUIError        bonobo_window_object_get                     (BonoboWindow      *win,
 								   const char        *path,
 								   Bonobo_Unknown    *object,
 								   CORBA_Environment *ev);
 
-GtkAccelGroup       *bonobo_window_get_accel_group                (BonoboWindow      *win);
-
 void                 bonobo_window_dump                           (BonoboWindow      *win,
 								   const char        *msg);
 
@@ -119,7 +123,7 @@ void                 bonobo_window_set_ui_container               (BonoboWindow
  * NB. popups are automaticaly removed on destroy, you probably don't
  * want to use this.
  */
-void                 bonobo_window_remove_popup                   (BonoboWindow   *win,
-								   const char     *path);
+void                 bonobo_window_remove_popup                   (BonoboWindow      *win,
+								   const char        *path);
 
 #endif /* _BONOBO_WINDOW_H_ */
