@@ -6,9 +6,6 @@
  *
  */
 #include <config.h>
-#include <gnome.h>
-
-#include <liboaf/liboaf.h>
 
 #include <bonobo.h>
 
@@ -714,6 +711,6 @@ generic_factory (BonoboGenericFactory *this, void *data)
 
 
 BONOBO_OAF_FACTORY ("OAFIID:Bonobo_Sample_Text_Factory",
-		    "bonobo-text-plain",
+		    "bonobo-text-plain", VERSION,
 		    generic_factory,
 		    NULL)
