@@ -45,7 +45,7 @@ typedef enum {
 	EFS_ERR_NODRIVER,
 	EFS_ERR_PERM,
 	EFS_ERR_NOSEEK,
-	EFS_ERR_EOF,
+	EFS_ERR_NOTYPE,
 	EFS_ERR_LAST        
 } EFSResult;
 
