@@ -186,14 +186,25 @@ create_default_inodes (IB1EFS *efs)
 	if (!(inode = ib1_inode_create(efs)) || (inode != IB1_IMAP_INODE))
 		return EFS_ERR_INT;
 	
-	if (!(inode = ib1_inode_create(efs))) return EFS_ERR_INT;
-
 	if (!(inode = ib1_inode_create(efs)) || (inode != IB1_ROOT_INODE))
 		return EFS_ERR_INT;
 
+	if (!(inode = ib1_inode_create(efs)) || (inode != IB1_TYPE_INODE))
+		return EFS_ERR_INT;
+
 	return EFS_ERR_OK;
 } 
 
+static void
+ib1_create_typefd (IB1EFS *efs)
+{
+	((EFS *)efs)->typefd = (EFSFile *)g_new0 (IB1File, 1);
+	((EFS *)efs)->typefd->efs = (EFS *)efs;
+	((EFS *)efs)->typefd->mode = (((EFS *)efs)->mode&EFS_RDWR) | EFS_FILE;
+	((IB1File *)((EFS *)efs)->typefd)->inode = IB1_TYPE_INODE;
+	ib1_inode_ref (efs, IB1_TYPE_INODE);
+}
+
 static EFSResult
 ib1_open (EFSDir **dir, EFSDriver *driver, const char *path, gint flags, 
 	  gchar *passwd)
@@ -252,6 +263,8 @@ ib1_open (EFSDir **dir, EFSDriver *driver, const char *path, gint flags,
 		efs->head.imap_start = ce->block;
 	}
 
+	ib1_create_typefd (efs);
+
 	(IB1Dir *)(*dir) = g_new0 (IB1Dir, 1);
 	(*dir)->efs = (EFS *)efs;
 	(*dir)->pos = 0;
@@ -304,6 +317,8 @@ ib1_create (EFSDir **dir, EFSDriver *driver, const char *path, gint flags,
 		return EFS_ERR_ERRNO;
 	}
 
+	ib1_create_typefd (efs);
+
 	(IB1Dir *)(*dir) = g_new0 (IB1Dir, 1);
 	(*dir)->efs = (EFS *)efs;
 	(*dir)->pos = 0;
