@@ -7,8 +7,6 @@
  * Copyright (c) 2000 Helix Code, Inc.
  */
 #include <config.h>
-#include <gnome.h>
-#include <liboaf/liboaf.h>
 #include <bonobo/bonobo.h>
 
 #include "bonobo-moniker-http.h"
@@ -85,6 +83,6 @@ bonobo_moniker_http_factory (BonoboGenericFactory *this, void *closure)
 }
 
 BONOBO_OAF_FACTORY ("OAFIID:Bonobo_Moniker_http_Factory",
-		    "http-moniker",
+		    "http-moniker", VERSION,
 		    bonobo_moniker_http_factory,
 		    NULL)
