@@ -25,9 +25,8 @@ typedef struct {
 GtkType          bonobo_stream_efs_get_type     (void);
 BonoboStream    *bonobo_stream_efs_open         (BonoboStorageEFS *storage,
 						 const CORBA_char *path, 
-						 Bonobo_Storage_OpenMode mode);
-BonoboStream    *bonobo_stream_efs_create       (BonoboStorageEFS *storage,
-						 const CORBA_char *path);
+						 Bonobo_Storage_OpenMode mode,
+						 CORBA_Environment *ev);
 gint             bonobo_mode_to_efs             (Bonobo_Storage_OpenMode mode);
 	
 END_GNOME_DECLS
